"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TransactionFilter = void 0;
class TransactionFilter {
    constructor(chainIDs, addresses, hashes, startTime, endTime) {
        this.startTime = startTime;
        this.endTime = endTime;
        if (chainIDs != undefined) {
            this.chainIDs = new Set(chainIDs);
        }
        if (hashes != undefined) {
            this.hashes = new Set(hashes.map((x) => x.toLowerCase()));
        }
        if (addresses != undefined) {
            this.addresses = new Set(addresses.map((x) => x.toLowerCase()));
        }
    }
    matches(tx) {
        if (this.chainIDs != undefined && !this.chainIDs.has(tx.chainId)) {
            return false;
        }
        if (this.hashes != undefined && !this.hashes.has(tx.hash.toLowerCase())) {
            return false;
        }
        if (this.startTime != undefined && this.startTime > tx.timestamp) {
            return false;
        }
        if (this.endTime != undefined && this.endTime < tx.timestamp) {
            return false;
        }
        if (this.addresses != undefined) {
            const txaddrs = Array.from(this._getDescendants(tx));
            if (txaddrs.length == 0) {
                return false;
            }
            if (!txaddrs.some((addr) => { var _a; return (_a = this.addresses) === null || _a === void 0 ? void 0 : _a.has(addr); })) {
                return false;
            }
        }
        return true;
    }
    _getDescendants(obj) {
        let result = new Set();
        for (const [key, value] of Object.entries(obj)) {
            if (value && typeof value === "object") {
                result = new Set([...result, ...this._getDescendants(value)]);
            }
            else if (typeof value === "string") {
                result.add(value.toLowerCase());
            }
        }
        return result;
    }
}
exports.TransactionFilter = TransactionFilter;
//# sourceMappingURL=TransactionFilter.js.map