import { TokenAndSecret, OAuth2Tokens } from "../../businessObjects/index.js";
import { VersionedObject, VersionedObjectMigrator } from "../../businessObjects/versioned/VersionedObject.js";
import { ESocialType } from "../../enum/index.js";
import { Integer, DiscordID, SocialPrimaryKey, Username, TwitterID } from "../../primitives/index.js";
export declare abstract class SocialProfile extends VersionedObject {
    pKey: SocialPrimaryKey;
    type: ESocialType;
    static CURRENT_VERSION: number;
    constructor(pKey: SocialPrimaryKey, type: ESocialType);
    getVersion(): number;
}
export declare class InvalidSocialProfile extends SocialProfile {
    pKey: SocialPrimaryKey;
    type: ESocialType;
    static CURRENT_VERSION: number;
    constructor(pKey: SocialPrimaryKey, type: ESocialType);
    getVersion(): number;
}
export declare class SocialProfileMigrator extends VersionedObjectMigrator<SocialProfile> {
    getCurrentVersion(): number;
    protected discordMigrator: DiscordProfileMigrator;
    protected twitterMigrator: TwitterProfileMigrator;
    constructor();
    protected factory(data: Record<string, unknown>): SocialProfile;
    protected getUpgradeFunctions(): Map<number, (data: Record<string, unknown>, version: number) => Record<string, unknown>>;
}
export declare class DiscordProfile extends SocialProfile {
    id: DiscordID;
    username: Username;
    displayName: string | null;
    discriminator: string;
    avatar: string | null;
    flags: Integer;
    oauth2Tokens: OAuth2Tokens;
    constructor(id: DiscordID, username: Username, displayName: string | null, discriminator: string, avatar: string | null, flags: Integer, oauth2Tokens: OAuth2Tokens);
    deriveKey(id: DiscordID): SocialPrimaryKey;
}
export declare class DiscordProfileMigrator {
    factory(data: Record<string, unknown>): DiscordProfile;
}
export declare class TwitterUserObject {
    id: TwitterID;
    username: Username;
    name?: string | undefined;
    constructor(id: TwitterID, username: Username, name?: string | undefined);
}
export declare class TwitterFollowData {
    following: TwitterUserObject[];
    followers: TwitterUserObject[];
    constructor(following: TwitterUserObject[], followers: TwitterUserObject[]);
}
export declare class TwitterProfile extends SocialProfile {
    userObject: TwitterUserObject;
    oAuth1a: TokenAndSecret;
    followData?: TwitterFollowData | undefined;
    constructor(userObject: TwitterUserObject, oAuth1a: TokenAndSecret, followData?: TwitterFollowData | undefined);
    deriveKey(id: TwitterID): SocialPrimaryKey;
}
export declare class TwitterProfileMigrator {
    factory(data: Record<string, unknown>): TwitterProfile;
}
//# sourceMappingURL=SocialProfile.d.ts.map