"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TwitterProfileMigrator = exports.TwitterProfile = exports.TwitterFollowData = exports.TwitterUserObject = exports.DiscordProfileMigrator = exports.DiscordProfile = exports.SocialProfileMigrator = exports.InvalidSocialProfile = exports.SocialProfile = void 0;
const VersionedObject_js_1 = require("../../businessObjects/versioned/VersionedObject.js");
const index_js_1 = require("../../enum/index.js");
const index_js_2 = require("../../primitives/index.js");
class SocialProfile extends VersionedObject_js_1.VersionedObject {
    constructor(pKey, type) {
        super();
        this.pKey = pKey;
        this.type = type;
    }
    getVersion() {
        return SocialProfile.CURRENT_VERSION;
    }
}
exports.SocialProfile = SocialProfile;
SocialProfile.CURRENT_VERSION = 1;
class InvalidSocialProfile extends SocialProfile {
    constructor(pKey, type) {
        super(pKey, type);
        this.pKey = pKey;
        this.type = type;
    }
    getVersion() {
        return InvalidSocialProfile.CURRENT_VERSION;
    }
}
exports.InvalidSocialProfile = InvalidSocialProfile;
InvalidSocialProfile.CURRENT_VERSION = 1;
class SocialProfileMigrator extends VersionedObject_js_1.VersionedObjectMigrator {
    constructor() {
        super();
        this.discordMigrator = new DiscordProfileMigrator();
        this.twitterMigrator = new TwitterProfileMigrator();
    }
    getCurrentVersion() {
        return SocialProfile.CURRENT_VERSION;
    }
    factory(data) {
        switch (data["type"]) {
            case index_js_1.ESocialType.DISCORD:
                return this.discordMigrator.factory(data);
            case index_js_1.ESocialType.TWITTER:
                return this.twitterMigrator.factory(data);
        }
        return new InvalidSocialProfile(// Cannot return null
        (0, index_js_2.SocialPrimaryKey)(data["pKey"]), index_js_1.ESocialType[data["type"]]);
    }
    getUpgradeFunctions() {
        return new Map();
    }
}
exports.SocialProfileMigrator = SocialProfileMigrator;
class DiscordProfile extends SocialProfile {
    constructor(id, username, displayName, discriminator, avatar, flags, oauth2Tokens) {
        super((0, index_js_2.SocialPrimaryKey)(`discord-${id}`), index_js_1.ESocialType.DISCORD);
        this.id = id;
        this.username = username;
        this.displayName = displayName;
        this.discriminator = discriminator;
        this.avatar = avatar;
        this.flags = flags;
        this.oauth2Tokens = oauth2Tokens;
    }
    deriveKey(id) {
        return (0, index_js_2.SocialPrimaryKey)(`discord-${id}`);
    }
}
exports.DiscordProfile = DiscordProfile;
class DiscordProfileMigrator {
    factory(data) {
        return new DiscordProfile((0, index_js_2.DiscordID)(data["id"]), (0, index_js_2.Username)(data["username"]), data["displayName"], data["discriminator"], data["avatar"], (0, index_js_2.Integer)(data["flags"]), data["oauth2Tokens"]);
    }
}
exports.DiscordProfileMigrator = DiscordProfileMigrator;
class TwitterUserObject {
    constructor(id, username, name) {
        this.id = id;
        this.username = username;
        this.name = name;
    }
}
exports.TwitterUserObject = TwitterUserObject;
class TwitterFollowData {
    constructor(following, followers) {
        this.following = following;
        this.followers = followers;
    }
}
exports.TwitterFollowData = TwitterFollowData;
class TwitterProfile extends SocialProfile {
    constructor(userObject, oAuth1a, followData) {
        super((0, index_js_2.SocialPrimaryKey)(`twitter-${userObject.id}`), index_js_1.ESocialType.TWITTER);
        this.userObject = userObject;
        this.oAuth1a = oAuth1a;
        this.followData = followData;
    }
    deriveKey(id) {
        return (0, index_js_2.SocialPrimaryKey)(`twitter-${id}`);
    }
}
exports.TwitterProfile = TwitterProfile;
class TwitterProfileMigrator {
    factory(data) {
        return new TwitterProfile(data["userObject"], data["oAuth1a"], data["followData"]
            ? data["followData"]
            : undefined);
    }
}
exports.TwitterProfileMigrator = TwitterProfileMigrator;
//# sourceMappingURL=SocialProfile.js.map