"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getEtherscanBaseURLForChain = exports.isAccountValidForChain = exports.getChainInfoByChainId = exports.getChainInfoByChain = exports.chainConfig = void 0;
const neverthrow_1 = require("neverthrow");
const businessObjects_1 = require("../businessObjects");
const enum_1 = require("../enum");
const errors_1 = require("../errors");
const primitives_1 = require("../primitives");
const getExplorerUrl = function (txHash) {
    return this.explorerURL + txHash;
};
exports.chainConfig = new Map([
    [
        (0, primitives_1.ChainId)(enum_1.EChain.DevDoodle),
        new businessObjects_1.ControlChainInformation("Dev Env Doodle Chain", (0, primitives_1.ChainId)(enum_1.EChain.DevDoodle), enum_1.EChain.DevDoodle, enum_1.EChainTechnology.EVM, true, "doodlechain", 4000, enum_1.EIndexer.Simulator, new businessObjects_1.NativeCurrencyInformation("DOODLE", 18, "DOODLE"), enum_1.EChainType.Hardhat, "", (0, primitives_1.EVMContractAddress)("0x5FC8d32690cc91D4c39d9d3abcBD16989F875707"), // Consent Contract Factory
        (0, primitives_1.EVMContractAddress)("0x610178dA211FEF7D417bC0e6FeD39F05609AD788"), // Crumbs Contract
        (0, primitives_1.EVMContractAddress)("0x9fE46736679d2D9a65F0992F2272dE9f3c7fa6e0"), // Metatransaction Forwarder Contract
        (0, primitives_1.EVMContractAddress)("0xB7f8BC63BbcaD18155201308C8f3540b07f84F5e")),
    ],
    [
        (0, primitives_1.ChainId)(enum_1.EChain.EthereumMainnet),
        new businessObjects_1.ChainInformation("Ethereum", (0, primitives_1.ChainId)(enum_1.EChain.EthereumMainnet), enum_1.EChain.EthereumMainnet, enum_1.EChainTechnology.EVM, true, "mainnet", 10000, enum_1.EIndexer.Ethereum, new businessObjects_1.NativeCurrencyInformation("ETH", 18, "ETH", "ethereum"), enum_1.EChainType.Mainnet, "https://etherscan.io/tx/", getExplorerUrl, (0, primitives_1.URLString)("https://api.etherscan.io/")),
    ],
    [
        (0, primitives_1.ChainId)(enum_1.EChain.Goerli),
        new businessObjects_1.ChainInformation("Goerli", (0, primitives_1.ChainId)(enum_1.EChain.Goerli), enum_1.EChain.Goerli, enum_1.EChainTechnology.EVM, true, "goerli", 10000, enum_1.EIndexer.Ethereum, new businessObjects_1.NativeCurrencyInformation("ETH", 18, "ETH", "ethereum"), enum_1.EChainType.Testnet, "https://goerli.etherscan.io/tx/", getExplorerUrl, (0, primitives_1.URLString)("https://api-goerli.etherscan.io/")),
    ],
    [
        (0, primitives_1.ChainId)(enum_1.EChain.Sepolia),
        new businessObjects_1.ChainInformation("Sepolia", (0, primitives_1.ChainId)(enum_1.EChain.Sepolia), enum_1.EChain.Sepolia, enum_1.EChainTechnology.EVM, true, "sepolia", 10000, enum_1.EIndexer.Ethereum, new businessObjects_1.NativeCurrencyInformation("ETH", 18, "ETH", "ethereum"), enum_1.EChainType.Testnet, "https://sepolia.etherscan.io/tx/", getExplorerUrl, (0, primitives_1.URLString)("https://api-sepolia.etherscan.io/")),
    ],
    // [
    //   ChainId(EChain.Kovan),
    //   new ChainInformation(
    //     "Kovan",
    //     ChainId(EChain.Kovan),
    //     EChain.Kovan,
    //     EChainTechnology.EVM,
    //     true,
    //     [],
    //     10000,
    //     EIndexer.EVM,
    //     new NativeCurrencyInformation("ETH", 18, "ETH"),
    //     EChainType.Testnet,
    //     "https://kovan.etherscan.io/tx/",
    //     getExplorerUrl,
    //   ),
    // ],
    [
        (0, primitives_1.ChainId)(enum_1.EChain.Mumbai),
        new businessObjects_1.ChainInformation("Mumbai", (0, primitives_1.ChainId)(enum_1.EChain.Mumbai), enum_1.EChain.Mumbai, enum_1.EChainTechnology.EVM, true, "polygon-mumbai", 10000, enum_1.EIndexer.Polygon, new businessObjects_1.NativeCurrencyInformation("MATIC", 18, "MATIC", "matic-network"), enum_1.EChainType.Testnet, "https://mumbai.polygonscan.com/tx/", getExplorerUrl, (0, primitives_1.URLString)("https://api-testnet.polygonscan.com/")),
    ],
    [
        (0, primitives_1.ChainId)(enum_1.EChain.Polygon),
        new businessObjects_1.ChainInformation("Polygon", (0, primitives_1.ChainId)(enum_1.EChain.Polygon), enum_1.EChain.Polygon, enum_1.EChainTechnology.EVM, true, "polygon-mainnet", 10000, enum_1.EIndexer.Polygon, new businessObjects_1.NativeCurrencyInformation("MATIC", 18, "MATIC", "matic-network"), enum_1.EChainType.Mainnet, "https=//polygonscan.com/tx/", getExplorerUrl, (0, primitives_1.URLString)("https://api.polygonscan.com/")),
    ],
    [
        (0, primitives_1.ChainId)(enum_1.EChain.Avalanche),
        new businessObjects_1.ChainInformation("Avalanche", (0, primitives_1.ChainId)(enum_1.EChain.Avalanche), enum_1.EChain.Avalanche, enum_1.EChainTechnology.EVM, true, "avalanche-mainnet", 4000, enum_1.EIndexer.EVM, new businessObjects_1.NativeCurrencyInformation("AVAX", 18, "AVAX", "avalanche-2"), enum_1.EChainType.Mainnet, "https=//snowtrace.io/block/", getExplorerUrl, (0, primitives_1.URLString)("https://api.snowtrace.io/")),
    ],
    [
        (0, primitives_1.ChainId)(enum_1.EChain.Fuji),
        new businessObjects_1.ControlChainInformation("Fuji", (0, primitives_1.ChainId)(enum_1.EChain.Fuji), enum_1.EChain.Fuji, enum_1.EChainTechnology.EVM, true, "avalanche-fuji", 4000, enum_1.EIndexer.EVM, new businessObjects_1.NativeCurrencyInformation("AVAX", 18, "AVAX", "avalanche-2"), enum_1.EChainType.Testnet, "https://testnet.snowtrace.io/block/", (0, primitives_1.EVMContractAddress)("0x5540122e78241679Da8d07A04A74D3a7f52aED97"), // Consent Contract Factory
        (0, primitives_1.EVMContractAddress)("0x49a04d6545b1511742033b0ddF6a2Ba880A69287"), // Crumbs Contract
        (0, primitives_1.EVMContractAddress)("0xdB5c885944d903Ac5c146eef400D2ee20572d357"), // Metatransaction Forwarder Contract
        (0, primitives_1.EVMContractAddress)("0x1007D88962A3c0c4A11649480168B6456355d91a"), // Sift Contract
        (0, primitives_1.URLString)("https://api-testnet.snowtrace.io/")),
    ],
    [
        (0, primitives_1.ChainId)(enum_1.EChain.Solana),
        new businessObjects_1.ChainInformation("Solana", (0, primitives_1.ChainId)(enum_1.EChain.Solana), enum_1.EChain.Solana, enum_1.EChainTechnology.Solana, true, "solana", 400, enum_1.EIndexer.Solana, new businessObjects_1.NativeCurrencyInformation("Sol", 9, "SOL", "solana"), enum_1.EChainType.Mainnet, "https://explorer.solana.com/tx/", getExplorerUrl, undefined, (0, primitives_1.CoinGeckoAssetPlatformID)("solana")),
    ],
    [
        (0, primitives_1.ChainId)(enum_1.EChain.Gnosis),
        new businessObjects_1.ChainInformation("Gnosis", (0, primitives_1.ChainId)(enum_1.EChain.Gnosis), enum_1.EChain.Gnosis, enum_1.EChainTechnology.EVM, true, "Gnosis", 10000, // average block mining time
        enum_1.EIndexer.Gnosis, new businessObjects_1.NativeCurrencyInformation("xDAI", 18, "xDAI", "xdai"), enum_1.EChainType.Mainnet, "https://gnosisscan.io/", getExplorerUrl, (0, primitives_1.URLString)("https://api.gnosisscan.io/")),
    ],
    [
        (0, primitives_1.ChainId)(enum_1.EChain.Binance),
        new businessObjects_1.ChainInformation("Binance", (0, primitives_1.ChainId)(enum_1.EChain.Binance), enum_1.EChain.Binance, enum_1.EChainTechnology.EVM, true, "binance", 10000, // average block mining time
        enum_1.EIndexer.Binance, new businessObjects_1.NativeCurrencyInformation("BNB", 18, "BNB", "binancecoin"), enum_1.EChainType.Mainnet, "https://api.bscscan.com/api", getExplorerUrl, (0, primitives_1.URLString)("https://api.bscscan.com/")),
    ],
    [
        (0, primitives_1.ChainId)(enum_1.EChain.Moonbeam),
        new businessObjects_1.ChainInformation("Moonbeam", (0, primitives_1.ChainId)(enum_1.EChain.Moonbeam), enum_1.EChain.Moonbeam, enum_1.EChainTechnology.EVM, true, "moonbeam", 10000, // average block mining time
        enum_1.EIndexer.Moonbeam, new businessObjects_1.NativeCurrencyInformation("GLMR", 18, "GLMR", "moonbeam"), enum_1.EChainType.Mainnet, "https://api-moonbeam.moonscan.io/api", getExplorerUrl, (0, primitives_1.URLString)("https://api-moonbeam.moonscan.io/")),
    ],
    [
        (0, primitives_1.ChainId)(enum_1.EChain.Arbitrum),
        new businessObjects_1.ChainInformation("Arbitrum", (0, primitives_1.ChainId)(enum_1.EChain.Arbitrum), enum_1.EChain.Arbitrum, enum_1.EChainTechnology.EVM, true, "arbitrum", 10000, // average block mining time
        enum_1.EIndexer.Arbitrum, new businessObjects_1.NativeCurrencyInformation("ARB", 18, "ARB", "arbitrum"), enum_1.EChainType.Mainnet, "https://api.arbiscan.io/api", getExplorerUrl, (0, primitives_1.URLString)("https://api.arbiscan.io/")),
    ],
    [
        (0, primitives_1.ChainId)(enum_1.EChain.Optimism),
        new businessObjects_1.ChainInformation("Optimism", (0, primitives_1.ChainId)(enum_1.EChain.Optimism), enum_1.EChain.Optimism, enum_1.EChainTechnology.EVM, true, "optimism", 10000, // average block mining time
        enum_1.EIndexer.Optimism, new businessObjects_1.NativeCurrencyInformation("OP", 18, "OP", "optimism"), enum_1.EChainType.Mainnet, "https://api-optimistic.etherscan.io/api", getExplorerUrl, (0, primitives_1.URLString)("https://api-optimistic.etherscan.io/")),
    ],
]);
function getChainInfoByChain(chain) {
    const chainInfo = exports.chainConfig.get((0, primitives_1.ChainId)(chain));
    if (chainInfo == null) {
        throw new Error(`Unknown chain ${chain}`);
    }
    return chainInfo;
}
exports.getChainInfoByChain = getChainInfoByChain;
function getChainInfoByChainId(chainId) {
    const chainInfo = exports.chainConfig.get(chainId);
    if (chainInfo == null) {
        throw new Error(`Unknown chain id ${chainId}`);
    }
    return chainInfo;
}
exports.getChainInfoByChainId = getChainInfoByChainId;
function isAccountValidForChain(chainId, account) {
    const targetChainInfo = getChainInfoByChainId(chainId);
    const accountChainInfo = getChainInfoByChain(account.sourceChain);
    return targetChainInfo.chainTechnology == accountChainInfo.chainTechnology;
}
exports.isAccountValidForChain = isAccountValidForChain;
function getEtherscanBaseURLForChain(chain) {
    try {
        const chainInfo = getChainInfoByChainId(chain);
        if (chainInfo.etherscanEndpointURL == undefined) {
            return (0, neverthrow_1.errAsync)(new errors_1.AccountIndexingError("no etherscan endpoint for chainID", chain));
        }
        return (0, neverthrow_1.okAsync)(chainInfo.etherscanEndpointURL);
    }
    catch (e) {
        return (0, neverthrow_1.errAsync)(new errors_1.AccountIndexingError("error fetching chain information", e));
    }
}
exports.getEtherscanBaseURLForChain = getEtherscanBaseURLForChain;
//# sourceMappingURL=chains.config.js.map