import { AdContent } from "../businessObjects/index.js";
import { ESDQLQueryReturn } from "../enum/index.js";
import { AccountAddress, ChainId, CompensationId, EVMContractAddress, IpfsCID, URLString, AdKey, UnixTimestamp, EAdDisplayType, ISO8601DateString } from "../primitives/index.js";
export interface ISDQLQueryObject {
    version: string;
    timestamp: ISO8601DateString;
    expiry: ISO8601DateString;
    description: string;
    business: string;
    ads: ISDQLAdsBlock;
    queries: {
        [queryId: string]: ISDQLQueryClause;
    };
    returns: {
        [returnsObject: string]: ISDQLReturnProperties;
        url: any;
    };
    compensations: ISDQLCompensationBlock;
    logic: ISDQLLogicObjects;
}
export interface ISDQLQueryClause {
    name: string;
    return: ESDQLQueryReturn;
    chain?: string;
    networkid?: string | string[];
    address?: string | string[];
    timestampRange?: ISDQLTimestampRange;
    contract?: ISDQLQueryContract;
    conditions?: ISDQLQueryConditions;
    enum_keys?: string[];
    object_schema?: ISDQLObjectSchema;
    patternProperties?: Record<string, unknown>;
}
export interface ISDQLObjectSchema {
    properties: any;
    patternProperties: any;
}
export interface ISDQLQueryContract {
    address: EVMContractAddress;
    networkid: string;
    function: string;
    direction: string;
    token: string;
    timestampRange: ISDQLTimestampRange;
}
export interface ISDQLTimestampRange {
    start: number | string;
    end: number | string;
}
export interface ISDQLQueryConditions {
    in: number[];
    ge: number;
    l: number;
    le: number;
    e: number;
    g: number;
    has: ISDQLHasObject;
}
export interface ISDQLHasObject {
    patternProperties: {
        [url: URLString]: number;
    };
}
export interface ISDQLReturnProperties {
    name: string;
    message?: string;
    query?: string;
}
export interface ISDQLAdsBlock {
    [index: AdKey]: ISDQLAd;
}
export interface ISDQLAd {
    name: string;
    content: AdContent;
    text: string | null;
    displayType: EAdDisplayType;
    weight: number;
    expiry: UnixTimestamp;
    keywords: string[];
}
export interface ISDQLCompensationBlock {
    [index: CompensationId]: ISDQLCompensationParameters | ISDQLCompensations;
    parameters: ISDQLCompensationParameters;
}
export interface ISDQLCompensations {
    name: string;
    image: IpfsCID | URLString | null;
    description: string;
    chainId: ChainId;
    callback: ISDQLCallback;
    alternatives?: CompensationId[];
}
export interface ISDQLCallback {
    parameters: string[];
    data: Record<string, unknown>;
}
export interface ISDQLCompensationParameters {
    [paramName: string]: unknown & {
        type: unknown;
        required: boolean;
        values?: unknown[];
    };
    recipientAddress: {
        type: AccountAddress;
        required: boolean;
    };
}
export interface ISDQLLogicObjects {
    returns: string[];
    ads: string[];
    compensations: string[];
}
//# sourceMappingURL=ISDQLQueryObject.d.ts.map